==> cayenne-4.1.1-src.tar.gz: cayenne-4.1.1-src/cayenne-jgroups/src/main/java/org/apache/cayenne/event/JGroupsServerModuleProvider.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.event;

import java.util.Collection;
import java.util.Collections;

import org.apache.cayenne.configuration.server.CayenneServerModuleProvider;
import org.apache.cayenne.configuration.server.ServerModule;
import org.apache.cayenne.di.Module;

/**
 * @since 4.0
 */
public class JGroupsServerModuleProvider implements CayenneServerModuleProvider {

    @Override
    public Module module() {
        return new JGroupsModule();
    }

    @Override
    public Class<? extends Module> moduleType() {
        return JGroupsModule.class;
    }

    @SuppressWarnings("unchecked")
    @Override
    public Collection<Class<? extends Module>> overrides() {
        Collection modules = Collections.singletonList(ServerModule.class);
        return modules;
    }
}

==> cayenne-4.2.3-src.tar.gz: cayenne-4.2.3-src/cayenne-jgroups/src/main/java/org/apache/cayenne/event/JGroupsServerModuleProvider.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.event;

import java.util.Collection;
import java.util.Collections;

import org.apache.cayenne.configuration.server.CayenneServerModuleProvider;
import org.apache.cayenne.configuration.server.ServerModule;
import org.apache.cayenne.di.Module;

/**
 * @since 4.0
 */
public class JGroupsServerModuleProvider implements CayenneServerModuleProvider {

    @Override
    public Module module() {
        return new JGroupsModule();
    }

    @Override
    public Class<? extends Module> moduleType() {
        return JGroupsModule.class;
    }

    @Override
    public Collection<Class<? extends Module>> overrides() {
        return Collections.singletonList(ServerModule.class);
    }
}
